@@ -77,6 +77,7 @@ class PostgreAsyncConnection():
         try:
             state = self._conn.poll()
         except (psycopg2.Warning, psycopg2.Error), ex:
+            print ex
             self._ioloop.remove_handler(fd)
             try:
                 #if ex.message.endswith("connection failed"):
@@ -135,7 +136,7 @@ class PostgreAsyncConnection():
 class PostgreAsyncClient(object):
     def __init__(self, dsn=None, database=None, username=None, password=None, host=None, port=None,
                  min_pool_size=0, max_pool_size=1, ioloop=None, connection_factory=None, cursor_factory=None,
-                 hstore=False, composite_types=None, init=None, **kwargs):
+                 hstore=False, register_unicode=True, composite_types=None, init=None, **kwargs):
         self._ioloop = ioloop or tornado.ioloop.IOLoop.instance()
         self._pool = set()
         self._wait_connections = set()
@@ -145,6 +146,9 @@ class PostgreAsyncClient(object):
 
         init_chain = []
 
+        if register_unicode:
+            init_chain.append(self._register_unicode)
+
         if hstore:
             init_chain.append(self._register_hstore)
 
@@ -188,6 +192,11 @@ class PostgreAsyncClient(object):
         conn.execute("SELECT 'hstore'::regtype::oid, 'hstore[]'::regtype::oid",
                      cursor_factory=psycopg2.extras.DictCursor, callback=_register_hstore_callback)
 
+    def _register_unicode(self, conn, callback):
+        psycopg2.extensions.register_type(psycopg2.extensions.UNICODE, conn._conn)
+        psycopg2.extensions.register_type(psycopg2.extensions.UNICODEARRAY, conn._conn)
+        callback()
+
     def _register_composite(self, name, schema="public"):
         def _register_composite_task(conn, callback):
             full_name = "%s.%s" % (schema, name)
@@ -246,7 +255,6 @@ class PostgreAsyncClient(object):
 
     def _disconnect(self, conn):
         conn.close()
-
         try:
             self._pool.remove(conn)
         except KeyError:
